@@ -101,10 +101,11 @@ static gnutls_session new_tls_session(int sock)
         int ret;
         gnutls_session session;
         const int kx_priority[] = {
+                GNUTLS_KX_ANON_DH,
 #ifndef GNUTLS_SRP_DISABLED
                 GNUTLS_KX_SRP, GNUTLS_KX_SRP_DSS, GNUTLS_KX_SRP_RSA,
 #endif
-                GNUTLS_KX_ANON_DH, 0 };
+                0 };
         union {
                 int fd;
                 void *ptr;
@@ -276,7 +277,7 @@ static int setup_server(const char *addr, unsigned int port, struct pollfd *pfd,
                         break;
                 }
         
-                ret = setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(int));
+                ret = setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, (void *) &on, sizeof(int));
                 if ( ret < 0 )
                         fprintf(stderr, "could not set SO_REUSEADDR: %s.\n", strerror(errno));
                 
