@@ -309,6 +309,14 @@ static int regex_match(const idmef_criterion_value_t *cv, idmef_criterion_operat
                 str = idmef_class_enum_to_string(class, idmef_value_get_enum(value));
         }
 
+        else if ( idmef_value_get_type(value) == IDMEF_VALUE_TYPE_DATA ) {
+                idmef_data_t *data;
+
+                data = idmef_value_get_data(value);
+                if ( idmef_data_get_type(data) == IDMEF_DATA_TYPE_CHAR_STRING )
+                        str = idmef_data_get_data(data);
+        }
+        
         if ( ! str )
                 return 0;
 
@@ -415,6 +423,34 @@ static void value_destroy(idmef_criterion_value_t *cv)
 
 
 
+/*
+ *
+ */
+static int do_match_cb(idmef_value_t *value, void *extra)
+{
+        int ret;
+        struct match_cb *mcb = extra;
+        idmef_criterion_value_t *cv = mcb->cv;
+        idmef_criterion_operator_t operator = mcb->operator;
+
+        if ( idmef_value_is_list(value) )
+                return idmef_value_iterate(value, do_match_cb, mcb);
+
+        /*
+         * In case we are matching against a list of values,
+         * a single mach is considered as a match. If the match fails
+         * we keep trying.
+         */
+        ret = cv->match(cv, operator, value);
+        if ( ret < 0 )
+                return ret;
+
+        if ( ret > 0 )
+                mcb->match++;
+        
+        return 0;
+}
+
 
 void idmef_criterion_value_destroy(idmef_criterion_value_t *value)
 {
@@ -467,7 +503,22 @@ int idmef_criterion_value_to_string(idmef_criterion_value_t *cv, prelude_string_
 int idmef_criterion_value_match(idmef_criterion_value_t *cv, idmef_value_t *value,
                                 idmef_criterion_operator_t op)
 {
-        return idmef_value_match(value, cv->value, op);
+        if ( cv->type == IDMEF_CRITERION_VALUE_TYPE_VALUE )
+                return idmef_value_match(value, cv->value, op);
+        else {        
+                int ret;
+                struct match_cb mcb;
+
+                mcb.cv = cv;
+                mcb.match = 0;
+                mcb.operator = op;
+        
+                ret = idmef_value_iterate(value, do_match_cb, &mcb);        
+                if ( ret < 0 )
+                        return ret;
+        
+                return mcb.match;
+        }
 }
 
 
@@ -689,7 +740,8 @@ int idmef_criterion_value_new_from_string(idmef_criterion_value_t **cv,
 
         else if ( operator & IDMEF_CRITERION_OPERATOR_REGEX &&
                   (idmef_path_get_value_type(path, -1) == IDMEF_VALUE_TYPE_STRING ||
-                   idmef_path_get_value_type(path, -1) == IDMEF_VALUE_TYPE_ENUM) )
+                   idmef_path_get_value_type(path, -1) == IDMEF_VALUE_TYPE_ENUM ||
+                   idmef_path_get_value_type(path, -1) == IDMEF_VALUE_TYPE_DATA) )
                 return idmef_criterion_value_new_regex(cv, value, operator);
 
         /*
