@@ -53,8 +53,9 @@
 
 
 
-#define MAX_DEPTH     16
-#define MAX_NAME_LEN 128
+#define MAX_DEPTH                16
+#define MAX_NAME_LEN            128
+#define HASH_DEFAULT_SIZE       128
 
 #define INDEX_UNDEFINED INT_MIN
 #define INDEX_FORBIDDEN (INT_MIN + 1)
@@ -137,7 +138,7 @@ static int initialize_path_cache_if_needed(void)
         if ( cached_path )
                 return 0;
                         
-        return prelude_hash_new(&cached_path, NULL, NULL, NULL, flush_cache_if_wanted);
+        return prelude_hash_new2(&cached_path, HASH_DEFAULT_SIZE, NULL, NULL, NULL, flush_cache_if_wanted);
 }
 
 
@@ -207,8 +208,10 @@ static int idmef_path_get_list_internal(idmef_value_t **value_list,
                         ret = idmef_path_get_internal(&value, path, depth, tmp, parent_class);
                 else {                        
                         ret = idmef_value_new(&value, path->elem[depth - 1].value_type, tmp);
-                        if ( ret == 0 )
+                        if ( ret == 0 ) {
+                                idmef_value_dont_have_own_data(value);
                                 ret = 1;
+                        }
                 }
 
                 if ( ret == 0 )
@@ -294,7 +297,7 @@ static int idmef_path_get_internal(idmef_value_t **value, const idmef_path_t *pa
                 return idmef_path_get_nth_internal(value, path, depth + 1, child, child_class, which);
         }
 
-        if ( parent_class < 0 || path->elem[path->depth - 1].value_type == IDMEF_VALUE_TYPE_ENUM ) {
+        if ( parent_class < 0 || (path->depth > 0 && path->elem[path->depth - 1].value_type == IDMEF_VALUE_TYPE_ENUM) ) {
                 *value = parent;
                 return 1;
         }
