@@ -29,14 +29,16 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <errno.h>
-#include <sys/ioctl.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include <termios.h>
 #include <gnutls/gnutls.h>
 
 #include "prelude-inttypes.h"
 
+#ifdef HAVE_SYS_IOCTL_H
+# include <sys/ioctl.h>
+#endif
+
 #ifdef HAVE_SYS_FILIO_H
 # include <sys/filio.h>
 #endif
@@ -57,6 +59,9 @@
 # define MIN(x, y) ((x) < (y) ? (x) : (y))
 #endif
 
+#ifdef WIN32
+# define ioctl ioctlsocket
+#endif
 
 struct prelude_io {
 
@@ -192,7 +197,7 @@ static int sys_close(prelude_io_t *pio)
 
 static ssize_t sys_pending(prelude_io_t *pio) 
 {
-        ssize_t ret = 0;
+        long ret = 0;
 
         if ( ioctl(pio->fd, FIONREAD, &ret) < 0 )
                 return prelude_error_from_errno(errno);
